# Generated by roxygen2: do not edit by hand

export(get_cik)
export(get_filing_history)
export(get_fundamentals)
export(get_fundamentals_batch)
importFrom(dplyr,arrange)
importFrom(dplyr,desc)
importFrom(dplyr,filter)
importFrom(dplyr,pull)
importFrom(dplyr,slice)
importFrom(httr,GET)
importFrom(httr,add_headers)
importFrom(httr,content)
importFrom(jsonlite,fromJSON)
importFrom(rlang,.data)
importFrom(tidyquant,tq_get)
